@@ -1,5 +1,5 @@
 package Selenium::Remote::Driver;
-$Selenium::Remote::Driver::VERSION = '0.1950'; # TRIAL
+$Selenium::Remote::Driver::VERSION = '0.1951'; # TRIAL
 # ABSTRACT: Perl Client for Selenium Remote Driver
 
 use Moo;
@@ -185,6 +185,16 @@ sub BUILD {
     }
 }
 
+sub new_from_caps {
+    my ($self, %args) = @_;
+
+    if (not exists $args{desired_capabilities}) {
+        $args{desired_capabilities} = {};
+    }
+
+    return $self->new(%args);
+}
+
 sub DESTROY {
     my ($self) = @_;
     return if $$ != $self->pid;
@@ -1070,7 +1080,7 @@ Selenium::Remote::Driver - Perl Client for Selenium Remote Driver
 
 =head1 VERSION
 
-version 0.1950
+version 0.1951
 
 =head1 SYNOPSIS
 
@@ -1179,6 +1189,7 @@ available here.
         'auto_close'           - <boolean>  - whether driver should end session on remote server on close.
         'default_finder'       - <string>   - choose default finder used for find_element* {class|class_name|css|id|link|link_text|name|partial_link_text|tag_name|xpath}
         'webelement_class'     - <string>   - sub-class of Selenium::Remote::WebElement if you wish to use an alternate WebElement class.
+        'ua'                   - LWP::UserAgent instance - if you wish to use a specific $ua, like from Test::LWP::UserAgent
 
 
     If no values are provided, then these defaults will be assumed:
@@ -1230,56 +1241,57 @@ available here.
     or
     my $driver = Selenium::Remote::Driver->new('default_finder' => 'css');
 
-=head2 new (desired_capabilities)
+=head2 new_from_caps
 
  Description:
 
     For experienced users who want complete control over the desired
-    capabilities, use the desired_capabilities hash option. This will
-    IGNORE all other browser-related desiredCapability options; the
-    only options that will be respected are those that are NOT part of
-    the Capabilities JSON Object as described in the Json Wire
-    Protocol. See Inputs below for more details.
+    capabilities, use this alternative constructor along with the
+    C<desired_capabilities> hash key in the init hash. Unlike "new",
+    this constructor will not assume any defaults for your desired
+    capabilities.
+
+    This alternate constructor IGNORES all other browser-related
+    desiredCapability options; the only options that will be respected
+    are those that are NOT part of the Capabilities JSON Object as
+    described in the Json Wire Protocol.
+
+ Input:
+    The only respected keys in the input hash are:
+
+        remote_server_addr   - STRING  - defaults to localhost
+        port                 - INTEGER - defaults to 4444
+        default_finder       - STRING  - defaults to xpath
+        webelement_class     - STRING  - defaults to Selenium::Remote::WebElement
+        auto_close           - BOOLEAN - defaults to 1
+        desired_capabilities - HASHREF - defaults to {}
+
+    Except for C<desired_capabilities>, these keys perform exactly the
+    same as listed in the regular "new" constructor.
 
     The hashref you pass in as desired_capabilities only gets json
     encoded before being passed to the Selenium server; no default
     options of any sort will be added.
 
-    Additionally, you must handle normalization of the input options
-    (like C<browser_name> vs C<browserName>) and take care of things
-    like encoding the firefox profile if applicable.
-
-    More information about the desired capabilities object is
-    available on the Selenium wiki:
+    This means you must handle normalization and casing of the input
+    options (like "browser_name" vs "browserName") and take care of
+    things like encoding the firefox profile if applicable. More
+    information about the desired capabilities object is available on
+    the Selenium wiki:
 
     https://code.google.com/p/selenium/wiki/JsonWireProtocol#Capabilities_JSON_Object
 
- Input:
-    If 'desired_capabilities' is one of your keys, these are the only
-    respected options:
-
-        'remote_server_addr'
-        'port'
-        'default_finder'
-        'webelement_class'
-        'auto_close'
-        'desired_capabilities'
-
-    All other options will be ignored.
-
  Output:
     Remote Driver object
 
  Usage:
-    my $driver = Selenium::Remote::Driver->new(
-        'desired_capabilities' => {
-            'browserName' => 'firefox'
-        }
+    my $driver = Selenium::Remote::Driver->new_from_caps(
+        'desired_capabilities' => {'browserName' => 'firefox'}
     );
 
     The above would generate a POST to the webdriver server at
-    localhost:4444 with the payload of {"desiredCapabilities":
-    {"browserName": "firefox" }}.
+    localhost:4444 with the exact payload of '{"desiredCapabilities":
+    {"browserName": "firefox" }}'.
 
 =head2 debug_on
 
